package
Version:
v1.10.0
Opens a new window with list of versions in this module.
Published: Mar 17, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Has returns true if (a & b) > 0.
Set returns a new mask of a | b.
String returns the stringified version of the mask.
Unset returns a new mask of a &^ b.
Bit is a type constraint that includes all unsigned integers.
type Bitmask[T Bit] interface {
Bit
MaxValue() T
}
Bitmask is a type constraint that can be used as a bitmask.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.